==> haskell-quickcheck-assertions-0.3.0-329-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-C4Lz5dGZYYzGKAF5sMxLrB
key:                  quickcheck-assertions-0.3.0-C4Lz5dGZYYzGKAF5sMxLrB
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  c923d79eb8bdfecdeb0877d4906931b3
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-C4Lz5dGZYYzGKAF5sMxLrB
depends:
    QuickCheck-2.14.3-EZ7TdgRzq7jKBweVl9M0jh base-4.17.2.1
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-330-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-HfATxURMs5t2PWFh2lPhUT
key:                  quickcheck-assertions-0.3.0-HfATxURMs5t2PWFh2lPhUT
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  7083518f29f742e35a3174ead25e2ba4
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-HfATxURMs5t2PWFh2lPhUT
depends:
    QuickCheck-2.14.3-7hqZHxjEzJA3sWW6zgGwOZ base-4.17.2.1
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
